@@ -101,27 +101,6 @@ static void xa_activate_entry (GtkToggleButton *button, ExtractDialog *extract_d
 		gtk_widget_set_sensitive(extract_dialog->specified_files_entry, FALSE);
 }
 
-static void xa_multi_extract_dialog_selection_changed (GtkTreeSelection *selection, MultiExtractDialog *multi_extract)
-{
-	GtkTreeIter iter;
-	GtkTreeModel *model;
-	XArchiveType type;
-	guint tag;
-	XArchive archive = {0};
-
-	if (gtk_tree_selection_get_selected (selection,&model,&iter))
-	{
-		gtk_tree_model_get(model, &iter, 3, &type, 4, &tag, -1);
-
-		archive.type = type;
-		archive.tag = tag;
-
-		(*archiver[type].ask)(&archive);
-
-		gtk_widget_set_sensitive(multi_extract->full_path, archive.can_full_path[0]);
-	}
-}
-
 static void xa_multi_extract_dialog_drag_data_received (GtkWidget *widget, GdkDragContext *context, gint x, gint y, GtkSelectionData *data, guint info, guint time, gpointer dialog_data)
 {
 	gchar **uris;
@@ -185,12 +164,12 @@ static void xa_activate_remove_button (GtkTreeModel *tree_model, GtkTreePath *pa
 		gtk_widget_set_sensitive (remove_button,TRUE );
 }
 
-static void remove_foreach_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, GList **rowref_list)
+static void remove_foreach_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, GSList **rowref_list)
 {
 	GtkTreeRowReference *rowref;
 
 	rowref = gtk_tree_row_reference_new(model,path);
-	*rowref_list = g_list_append(*rowref_list,rowref);
+	*rowref_list = g_slist_append(*rowref_list, rowref);
 }
 
 static void xa_multi_extract_dialog_remove_files (GtkButton *button, MultiExtractDialog *multi_extract)
@@ -199,8 +178,8 @@ static void xa_multi_extract_dialog_remove_files (GtkButton *button, MultiExtrac
 	GtkTreeSelection *sel;
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	GList *rr_list = NULL;
-	GList *node;
+	GSList *rr_list = NULL;
+	GSList *node;
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(multi_extract->treeview));
 	sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(multi_extract->treeview));
@@ -211,17 +190,30 @@ static void xa_multi_extract_dialog_remove_files (GtkButton *button, MultiExtrac
 		path = gtk_tree_row_reference_get_path((GtkTreeRowReference *)node->data);
 		if (path)
 		{
-			if ( gtk_tree_model_get_iter(GTK_TREE_MODEL(model),&iter,path))
+			if (gtk_tree_model_get_iter(model, &iter, path))
 			{
+				gboolean overwrite, full_path;
+
+				gtk_tree_model_get(model, &iter, 5, &overwrite, 6, &full_path, -1);
 				gtk_list_store_remove(multi_extract->liststore, &iter);
-				multi_extract->nr--;
+
+				multi_extract->nr_total--;
+
+				if (!overwrite)
+					multi_extract->nr_no_overwrite--;
+
+				if (!full_path)
+					multi_extract->nr_no_full_path--;
 			}
 			gtk_tree_path_free(path);
 		}
 	}
-	if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model),&iter)== FALSE)
-		gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
-	g_list_free_full(rr_list, (GDestroyNotify) gtk_tree_row_reference_free);
+
+	gtk_widget_set_sensitive(GTK_WIDGET(button), multi_extract->nr_total);
+	gtk_widget_set_sensitive(multi_extract->overwrite, multi_extract->nr_no_overwrite == 0);
+	gtk_widget_set_sensitive(multi_extract->full_path, multi_extract->nr_no_full_path == 0);
+
+	g_slist_free_full(rr_list, (GDestroyNotify) gtk_tree_row_reference_free);
 }
 
 static gchar *xa_multi_extract_one_archive (MultiExtractDialog *multi_extract, gchar *filename, gboolean overwrite, gboolean full_path, gchar *dest_path)
@@ -271,11 +263,8 @@ static gchar *xa_multi_extract_one_archive (MultiExtractDialog *multi_extract, g
 
 	xa_detect_encrypted_archive(archive);
 
-	if (archive->has_password)
-	{
-		if (!xa_check_password(archive))
-			error = _("You missed the password!");
-	}
+	if (archive->has_password && !xa_check_password(archive))
+		error = _("You missed the password!");
 
 	if (!error)
 	{
@@ -291,6 +280,19 @@ static gchar *xa_multi_extract_one_archive (MultiExtractDialog *multi_extract, g
 	return error;
 }
 
+static void xa_multi_extract_dialog_clear (MultiExtractDialog *multi_extract)
+{
+	gtk_list_store_clear(multi_extract->liststore);
+
+	multi_extract->nr_total = 0;
+	multi_extract->nr_no_overwrite = 0;
+	multi_extract->nr_no_full_path = 0;
+
+	gtk_widget_set_sensitive(multi_extract->remove, FALSE);
+	gtk_widget_set_sensitive(multi_extract->overwrite, TRUE);
+	gtk_widget_set_sensitive(multi_extract->full_path, TRUE);
+}
+
 static void toggle_overwrite_update_freshen (GtkToggleButton *button, ExtractDialog *extract_dialog)
 {
 	gboolean active = gtk_toggle_button_get_active(button);
@@ -343,7 +345,7 @@ ExtractDialog *xa_create_extract_dialog ()
 	gtk_entry_set_activates_default(GTK_ENTRY(extract_dialog->destination_path_entry), TRUE);
 
 	extract_dialog->ensure_directory = gtk_check_button_new_with_mnemonic(_("Ensure a containing directory"));
-	gtk_widget_set_tooltip_text(extract_dialog->ensure_directory, _("Ensure that the contents of the extracted archive is always in a containing directory"));
+	gtk_widget_set_tooltip_text(extract_dialog->ensure_directory, _("Ensure that the contents of the extracted archive is always in a containing directory."));
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->ensure_directory), FALSE);
 
 	alignment = gtk_alignment_new(0, 0.5, 1, 1);
@@ -399,14 +401,14 @@ ExtractDialog *xa_create_extract_dialog ()
 	gtk_container_add(GTK_CONTAINER(alignment), vbox2);
 
 	extract_dialog->full_path = gtk_radio_button_new_with_mnemonic(NULL, _("With full path"));
-	gtk_widget_set_tooltip_text(extract_dialog->full_path, _("The archive's complete directory structure is recreated in the extraction directory"));
+	gtk_widget_set_tooltip_text(extract_dialog->full_path, _("The archive's complete directory structure is recreated in the extraction directory."));
 	gtk_box_pack_start(GTK_BOX(vbox2), extract_dialog->full_path, TRUE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->full_path), FALSE);
 
 	group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(extract_dialog->full_path));
 
 	extract_dialog->relative_path = gtk_radio_button_new_with_mnemonic(group, _("Without parent path"));
-	gtk_widget_set_tooltip_text(extract_dialog->relative_path, _("The archive's directory structure is recreated in the extraction directory, but with the parent directories of the selected files removed"));
+	gtk_widget_set_tooltip_text(extract_dialog->relative_path, _("The archive's directory structure is recreated in the extraction directory, but with the parent directories of the selected files removed."));
 	gtk_box_pack_start(GTK_BOX(vbox2), extract_dialog->relative_path, TRUE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->relative_path), FALSE);
 	g_signal_connect(extract_dialog->relative_path, "toggled", G_CALLBACK(xa_toggle_relative_path_radio), extract_dialog);
@@ -414,7 +416,7 @@ ExtractDialog *xa_create_extract_dialog ()
 	group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(extract_dialog->relative_path));
 
 	extract_dialog->without_path = gtk_radio_button_new_with_mnemonic(group, _("Without any path"));
-	gtk_widget_set_tooltip_text(extract_dialog->without_path, _("The archive's directory structure is not recreated; all files are placed in the extraction directory"));
+	gtk_widget_set_tooltip_text(extract_dialog->without_path, _("The archive's directory structure is not recreated; all files are placed in the extraction directory."));
 	gtk_box_pack_start(GTK_BOX(vbox2), extract_dialog->without_path, TRUE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->without_path), FALSE);
 
@@ -430,7 +432,7 @@ ExtractDialog *xa_create_extract_dialog ()
 	gtk_container_add(GTK_CONTAINER(alignment), vbox2);
 
 	extract_dialog->touch = gtk_check_button_new_with_mnemonic(_("Touch files"));
-	gtk_widget_set_tooltip_text(extract_dialog->touch, _("When this option is used, the modification times of the files will be the times of extraction instead of the times recorded in the archive"));
+	gtk_widget_set_tooltip_text(extract_dialog->touch, _("When this option is used, the modification times of the files will be the times of extraction instead of the times recorded in the archive."));
 	gtk_box_pack_start(GTK_BOX(vbox2), extract_dialog->touch, TRUE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->touch), FALSE);
 
@@ -440,13 +442,13 @@ ExtractDialog *xa_create_extract_dialog ()
 	g_signal_connect(G_OBJECT(extract_dialog->overwrite), "toggled", G_CALLBACK(toggle_overwrite_update_freshen), extract_dialog);
 
 	extract_dialog->update = gtk_check_button_new_with_mnemonic(_("Update existing files"));
-	gtk_widget_set_tooltip_text(extract_dialog->update, _("This option performs the same function as the freshen one, extracting files that are newer than those with the same name on disk, and in addition it extracts those files that do not already exist on disk"));
+	gtk_widget_set_tooltip_text(extract_dialog->update, _("This option performs the same function as the freshen one, extracting files that are newer than those with the same name on disk, and in addition it extracts those files that do not already exist on disk."));
 	gtk_box_pack_start(GTK_BOX(vbox2), extract_dialog->update, TRUE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->update), FALSE);
 	g_signal_connect(G_OBJECT(extract_dialog->update), "toggled", G_CALLBACK(toggle_overwrite_update_freshen), extract_dialog);
 
 	extract_dialog->freshen = gtk_check_button_new_with_mnemonic(_("Freshen existing files only"));
-	gtk_widget_set_tooltip_text(extract_dialog->freshen, _("Extract only those files that already exist on disk and that are newer than the disk copies"));
+	gtk_widget_set_tooltip_text(extract_dialog->freshen, _("Extract only those files that already exist on disk and that are newer than the disk copies."));
 	gtk_box_pack_start(GTK_BOX(vbox2), extract_dialog->freshen, TRUE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(extract_dialog->freshen), FALSE);
 	g_signal_connect(G_OBJECT(extract_dialog->freshen), "toggled", G_CALLBACK(toggle_overwrite_update_freshen), extract_dialog);
@@ -489,6 +491,8 @@ ExtractDialog *xa_create_extract_dialog ()
 
 void xa_set_extract_dialog_options (ExtractDialog *extract_dialog, gint selected, XArchive *archive)
 {
+	extract_dialog->archive = archive;
+
 	if (progress)
 		gtk_widget_hide(progress->window);
 
@@ -550,8 +554,6 @@ void xa_set_extract_dialog_options (ExtractDialog *extract_dialog, gint selected
 	gtk_widget_set_sensitive(extract_dialog->label_password, archive->has_password);
 	gtk_widget_set_sensitive(extract_dialog->password_entry, archive->has_password);
 
-	extract_dialog->archive = archive;
-
 	gtk_widget_show_all(extract_dialog->dialog);
 }
 
@@ -699,7 +701,6 @@ MultiExtractDialog *xa_create_multi_extract_dialog ()
 	GTK_COMPAT_TOOLTIPS;
 	MultiExtractDialog *multi_extract;
 	GtkWidget *vbox, *window, *alignment, *hbox, *hbox2, *button, *frame, *image, *label;
-	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	int col;
 	GSList *group;
@@ -722,17 +723,16 @@ MultiExtractDialog *xa_create_multi_extract_dialog ()
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(window), GTK_SHADOW_IN);
 
-	multi_extract->liststore = gtk_list_store_new(5, G_TYPE_STRING, G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_INT, G_TYPE_UINT);
+	multi_extract->liststore = gtk_list_store_new(7, G_TYPE_STRING, G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_INT, G_TYPE_UINT, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 	multi_extract->treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(multi_extract->liststore));
 
+	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(multi_extract->treeview)), GTK_SELECTION_MULTIPLE);
+
 	gtk_container_add(GTK_CONTAINER(window), multi_extract->treeview);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(multi_extract->treeview), TRUE);
 	gtk_drag_dest_set(multi_extract->treeview, GTK_DEST_DEFAULT_ALL, drop_targets, G_N_ELEMENTS(drop_targets), GDK_ACTION_COPY);
 	g_signal_connect(G_OBJECT(multi_extract->treeview), "drag-data-received", G_CALLBACK(xa_multi_extract_dialog_drag_data_received), multi_extract);
 
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(multi_extract->treeview));
-	g_signal_connect(selection, "changed", G_CALLBACK(xa_multi_extract_dialog_selection_changed), multi_extract);
-
 	renderer = gtk_cell_renderer_text_new();
 
 	for (col = 0; col < 3; col++)
@@ -844,7 +844,7 @@ MultiExtractDialog *xa_create_multi_extract_dialog ()
 void xa_multi_extract_dialog_add_file (gchar *file_path, MultiExtractDialog *multi_extract)
 {
 	GtkTreeIter iter;
-	gchar *path, *path_utf8, *file, *file_utf8;
+	gchar *path, *path_utf8, *file_utf8;
 	ArchiveType xa;
 	XArchive archive = {0};
 	struct stat my_stat;
@@ -859,7 +859,7 @@ void xa_multi_extract_dialog_add_file (gchar *file_path, MultiExtractDialog *mul
 	{
 		gchar *name, *msg;
 
-		name = g_path_get_basename(file_path);
+		name = g_filename_display_basename(file_path);
 		msg = g_strdup_printf(_("The proper archiver for \"%s\" is not installed!"), name);
 		xa_show_message_dialog(GTK_WINDOW(xa_main_window), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Sorry, this archive format is not supported:"), msg);
 		g_free(msg);
@@ -878,17 +878,27 @@ void xa_multi_extract_dialog_add_file (gchar *file_path, MultiExtractDialog *mul
 		return;
 	}
 
+	if (!archive.can_overwrite)
+	{
+		multi_extract->nr_no_overwrite++;
+		gtk_widget_set_sensitive(multi_extract->overwrite, FALSE);
+	}
+
+	if (!archive.can_full_path[0])
+	{
+		multi_extract->nr_no_full_path++;
+		gtk_widget_set_sensitive(multi_extract->full_path, FALSE);
+	}
+
 	stat (file_path,&my_stat);
 	file_size = my_stat.st_size;
 	path = xa_remove_level_from_path(file_path);
 	path_utf8 = g_filename_display_name(path);
-	file = g_path_get_basename(file_path);
-	file_utf8 = g_filename_display_name(file);
+	file_utf8 = g_filename_display_basename(file_path);
 	gtk_list_store_append(multi_extract->liststore, &iter);
-	gtk_list_store_set(multi_extract->liststore, &iter, 0, file_utf8, 1, file_size, 2, path_utf8, 3, xa.type, 4, xa.tag, -1);
-	multi_extract->nr++;
+	gtk_list_store_set(multi_extract->liststore, &iter, 0, file_utf8, 1, file_size, 2, path_utf8, 3, xa.type, 4, xa.tag, 5, archive.can_overwrite, 6, archive.can_full_path[0], -1);
+	multi_extract->nr_total++;
 	g_free(file_utf8);
-	g_free(file);
 	g_free(path_utf8);
 	g_free(path);
 }
@@ -898,7 +908,7 @@ void xa_multi_extract_dialog (MultiExtractDialog *multi_extract)
 	GtkTreeIter iter;
 	gchar *filename, *filename_local, *file, *path, *message, *name, *dest_path = NULL;
 	GString *output = g_string_new("");
-	gboolean overwrite = FALSE, full_path;
+	gboolean overwrite, full_path;
 	gint response;
 	double percent = 0.0;
 
@@ -921,7 +931,7 @@ run:
 	response = gtk_dialog_run(GTK_DIALOG(multi_extract->dialog));
 	if (response == GTK_RESPONSE_CANCEL || response == GTK_RESPONSE_DELETE_EVENT)
 	{
-		gtk_list_store_clear(multi_extract->liststore);
+		xa_multi_extract_dialog_clear(multi_extract);
 		gtk_widget_hide(multi_extract->dialog);
 		return;
 	}
@@ -941,16 +951,16 @@ run:
 	}
 	gtk_widget_hide(multi_extract->dialog);
 
-	if (gtk_widget_is_sensitive(multi_extract->overwrite))
-		overwrite = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(multi_extract->overwrite));
-	double fraction = 1.0 / multi_extract->nr;
+	overwrite = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(multi_extract->overwrite));
+	full_path = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(multi_extract->full_path));
+
+	double fraction = 1.0 / multi_extract->nr_total;
 
 	xa_show_progress_bar(NULL);
 
 	do
 	{
 		gtk_tree_model_get(GTK_TREE_MODEL(multi_extract->liststore), &iter, 0, &file, 2, &path, -1);
-		full_path = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(multi_extract->full_path));
 		filename = g_strconcat (path,"/",file,NULL);
 		xa_increase_progress_bar(progress, filename, percent);
 		g_free(file);
@@ -983,9 +993,7 @@ run:
 	if (dest_path != NULL)
 		g_free(dest_path);
 
-	multi_extract->nr = 0;
-	gtk_list_store_clear(multi_extract->liststore);
-	gtk_widget_set_sensitive(multi_extract->remove, FALSE);
+	xa_multi_extract_dialog_clear(multi_extract);
 }
 
 void xa_execute_extract_commands (XArchive *archive, GSList *list, gboolean strip)
