@@ -48,6 +48,7 @@
 #define compress (archive->type == XARCHIVETYPE_COMPRESS)
 #define lrzip    (archive->type == XARCHIVETYPE_LRZIP)
 #define lz4      (archive->type == XARCHIVETYPE_LZ4)
+#define mozlz4   (archive->type == XARCHIVETYPE_LZ4 && archive->tag == 'm')
 #define rzip     (archive->type == XARCHIVETYPE_RZIP)
 #define xz       (archive->type == XARCHIVETYPE_XZ)
 #define zstd     (archive->type == XARCHIVETYPE_ZSTD)
@@ -245,12 +246,12 @@ static void xa_gzip_et_al_can (XArchive *archive, gboolean can)
 	archive->can_extract = can;
 	archive->can_password = (can && lrzip && lrzip_can_password);
 	archive->can_overwrite = can;
-	archive->can_move = can;
+	archive->can_remove = can;
 
 	/* only if archive is new and empty */
 	archive->can_add = (can && archiver[archive->type].is_compressor);
 
-	archive->can_compress = (can && archiver[archive->type].is_compressor);
+	archive->can_compress = (can && archiver[archive->type].is_compressor && !mozlz4);
 	archive->compressor = xa_gzip_et_al_compressor(archive);
 	archive->compression = archive->compressor.preset;
 }
@@ -639,8 +640,8 @@ void xa_gzip_et_al_list (XArchive *archive)
 	if (archive->type == XARCHIVETYPE_LZ4 && TAGTYPE(archive->tag) == 'm')
 	{
 		int skip, offset;
-		uint32_t uncompressed, blocksize;
-		guint8 flg, bd, hc, endmark[4] = "\x00\x00\x00\x00";
+		uint32_t uncompressed, blocksize, endmark = 0;
+		guint8 flg, bd, hc;
 		size_t bytes;
 
 		file = fopen(archive->path[0], "r");
@@ -718,9 +719,9 @@ void xa_gzip_et_al_list (XArchive *archive)
 
 		/* copy lz4 data */
 		while ((bytes = fread(buffer, 1, sizeof(buffer), file)) > 0)
-			fwrite(buffer, 1, bytes, wfile);
+			fwrite(buffer, bytes, 1, wfile);
 
-		fwrite(endmark, sizeof(endmark), 1, wfile);
+		fwrite(&endmark, sizeof(endmark), 1, wfile);
 
 		fclose(wfile);
 		fclose(file);
@@ -735,9 +736,8 @@ void xa_gzip_et_al_list (XArchive *archive)
 		archive->path[3] = g_strdup(archive->path[1]);
 	}
 
-	if (archive->has_password)
-		if (!xa_check_password(archive))
-			return;
+	if (archive->has_password && !xa_check_password(archive))
+		return;
 
 	password_str = xa_gzip_et_al_password_str(archive->password, archive->type);
 	archive_path = xa_quote_shell_command(archive->path[2], TRUE);
@@ -1006,16 +1006,31 @@ gboolean xa_gzip_et_al_extract (XArchive *archive, GSList *file_list)
 void xa_gzip_et_al_add (XArchive *archive, GSList *file_list)
 {
 	GString *files;
-	gchar *compression, *files_str, *archive_path, *move, *password_str, *out, *command;
+	gchar *compression, *files_str, *archive_path, *move, *password_str, *args, *command;
+	struct stat st;
 	gboolean success;
 
+	if (mozlz4)
+	{
+		gchar *file;
+
+		if (!xa_create_working_directory(archive))
+			return;
+
+		archive->path[2] = g_strconcat(archive->working_dir, "/", "xa-tmp.lz4", NULL);
+
+		file = g_strconcat(archive->child_dir, "/", file_list->data, NULL);
+		stat(file, &st);
+		g_free(file);
+	}
+
 	compression = g_strdup_printf("%hu", archive->compression);
 
 	files = xa_quote_filenames(file_list, NULL, DIR_WITH_SLASH);
 	files_str = xa_escape_bad_chars(files->str, "\"");
 	archive_path = xa_quote_shell_command(archive->path[2] ? archive->path[2] : archive->path[0], TRUE);
 
-	if (archive->do_move)
+	if (archive->do_remove)
 		move = g_strconcat(" rm --", files_str, NULL);
 	else
 		move = g_strdup("");
@@ -1023,23 +1038,59 @@ void xa_gzip_et_al_add (XArchive *archive, GSList *file_list)
 	password_str = xa_gzip_et_al_password_str(archive->password, archive->type);
 
 	if (lrzip || rzip)
-		out = g_strconcat(lrzip ? " -fo " : " -kfo ", archive_path, " --", files_str, NULL);
+		args = g_strconcat(lrzip ? " -fo " : " -kfo ", archive_path, " --", files_str, NULL);
 	else
-		out = g_strconcat(" -c", bzip ? "" : " --", files_str, " > ", archive_path, NULL);
+		args = g_strconcat(" -c", bzip ? "" : " --", files_str, " > ", archive_path, NULL);
 
-	command = g_strconcat("sh -c \"exec ", archiver[archive->type].program[0], " -", compress || bzip3 ? "b " : (lrzip ? (*compression == '0' ? "n" : "L ") : ""), lrzip && (*compression == '0') ? "" : compression, password_str, out, "\"", NULL);
+	command = g_strconcat("sh -c \"exec ", archiver[archive->type].program[0], " -", compress || bzip3 ? "b " : (lrzip ? (*compression == '0' ? "n" : "L ") : ""), lrzip && (*compression == '0') ? "" : (mozlz4 ? "l" : compression), password_str, args, "\"", NULL);
 	success = xa_run_command(archive, command);
 
 	g_free(command);
 	command = NULL;
 
+	if (success && mozlz4)
+	{
+		FILE *in, *out;
+		uint32_t size;
+		size_t bytes;
+		char buffer[4096];
+
+		in = fopen(archive->path[2], "r");
+
+		if (!in)
+			goto finish;
+
+		out = fopen(archive->path[0], "w");
+
+		if (!out)
+		{
+			fclose(in);
+			goto finish;
+		}
+
+		fwrite(MOZLZ4_MAGIC, 8, 1, out);
+		size = htole32((uint32_t) st.st_size);
+		fwrite(&size, sizeof(size), 1, out);
+
+		if (fseek(in, 8, SEEK_SET) == 0)
+		{
+			/* copy lz4 data */
+			while ((bytes = fread(buffer, 1, sizeof(buffer), in)) > 0)
+				fwrite(buffer, bytes, 1, out);
+		}
+
+		fclose(out);
+		fclose(in);
+	}
+
 	if (success)
 	{
 		command = g_strconcat("sh -c \"exec", move, "\"", NULL);
 		archive->status = XARCHIVESTATUS_ADD;   // restore status
 	}
 
-	g_free(out);
+finish:
+	g_free(args);
 	g_free(password_str);
 	g_free(move);
 	g_free(archive_path);
