@@ -38,7 +38,8 @@ void xa_zpaq_ask (XArchive *archive)
 	archive->can_full_path[0] = TRUE;
 	archive->can_full_path[1] = TRUE;   // n.b.: adds leading slash
 	archive->can_overwrite = TRUE;
-	archive->can_recurse = TRUE;
+	archive->can_recurse[0] = TRUE;
+	archive->can_recurse[1] = FORCED;
 	archive->can_compress = TRUE;
 	archive->compressor = zpaq_compressor;
 	archive->compression = archive->compressor.preset;
@@ -215,7 +216,7 @@ gboolean xa_zpaq_extract (XArchive *archive, GSList *file_list)
 		list = list->next;
 	}
 
-	files = xa_quote_filenames(file_list, NULL, TRUE);
+	files = xa_quote_filenames(file_list, NULL, DIR_WITH_SLASH);
 	archive->child_dir = extract_to;
 	command = g_strconcat(archiver[archive->type].program[0], " x ",
 	/* do_overwrite can be ignored in new temporary directory */
@@ -263,7 +264,7 @@ void xa_zpaq_add (XArchive *archive, GSList *file_list)
 
 	compression = g_strdup_printf("%hu", archive->compression);
 
-	files = xa_quote_filenames(file_list, "-", TRUE);
+	files = xa_quote_filenames(file_list, "-", DIR_WITH_SLASH);
 	command = g_strconcat(archiver[archive->type].program[0], " a ",
 	                      archive->path[1], files->str,
 	                      " -m", compression, NULL);
@@ -306,7 +307,7 @@ void xa_zpaq_delete (XArchive *archive, GSList *file_list)
 
 	if (!command)
 	{
-		files = xa_quote_filenames(file_list, NULL, TRUE);
+		files = xa_quote_filenames(file_list, NULL, DIR_WITH_SLASH);
 		archive->child_dir = workdir;
 		command = g_strconcat(archiver[archive->type].program[0], " a ", archive->path[1], files->str, NULL);
 		g_string_free(files, TRUE);
